@@ -17,10 +17,8 @@ import os.path
 import pkgutil
 
 import click
-from click.core import Context
-from click.formatting import HelpFormatter
 
-from osducli.click_cli import State
+from osducli.click_cli import CustomClickGroup, State
 
 
 def get_commands_from_pkg(pkg) -> dict:
@@ -32,13 +30,11 @@ def get_commands_from_pkg(pkg) -> dict:
     Returns:
         dict: [description]
     """
+    # groups with only 1 command that should be kept as groups for future expandability
     keep_groups = [
         "osducli.commands.legal",
         "osducli.commands.list",
         "osducli.commands.unit",
-        "osducli.commands.schema",
-        "osducli.commands.search",
-        "osducli.commands.workflow",
     ]
     pkg_obj = importlib.import_module(pkg)
 
@@ -61,51 +57,21 @@ def get_commands_from_pkg(pkg) -> dict:
                 commands[module.name.replace("_", "-")] = click_command
             elif len(group_commands) >= 1:
                 # print(f"Add group {module.name.replace('_', '-')}\n{group_commands}")
-                commands[module.name.replace("_", "-")] = click.Group(
+                commands[module.name.replace("_", "-")] = CustomClickGroup(
                     context_settings={"help_option_names": ["-h", "--help"]},
                     help=module_obj.__doc__,
                     commands=group_commands,
                 )
             # else:
             #     print(f"Skip group {module.name.replace('_', '-')}")
-    # if len(commands) > 0:
-    #     print(f"return {len(commands)}")
-    #     print(commands)
+
     return commands
 
 
-class CustomHelpGroup(click.Group):
-    """Custom help text for the base click command
-
-    Args:
-        click ([type]): [description]
-    """
-
-    def format_help(self, ctx, formatter):
-        self.format_usage(ctx, formatter)
-        self.format_help_text(ctx, formatter)
-        # click.Command.format_options(self, ctx, formatter)
-        self.format_commands(ctx, formatter)
-        self.format_epilog(ctx, formatter)
-        self.format_global_options(ctx, formatter)
-
-    def format_global_options(self, ctx: Context, formatter: HelpFormatter) -> None:
-        """Writes all the options into the formatter if they exist."""
-        opts = []
-        for param in self.get_params(ctx):
-            _rv = param.get_help_record(ctx)
-            if _rv is not None:
-                opts.append(_rv)
-
-        if opts:
-            with formatter.section("Global Options"):
-                formatter.write_dl(opts)
-
-
 # Main entry point for OSDU CLI.
 # noqa: W606,W605 pylint: disable=W1401
 @click.group(
-    # cls=CustomHelpGroup,
+    cls=CustomClickGroup,
     commands=get_commands_from_pkg("osducli.commands"),
     context_settings={"help_option_names": ["-h", "--help"]},
 )
@@ -121,7 +87,10 @@ def cli(ctx):
     Welcome to the OSDU CLI!
 
     \033[33mNote: This is currently a work in progress and may contain bugs or breaking changes.
-    Please share ideas / issues on the git page.\033[39m
+    Please share ideas / issues on the git page:
+
+    \b
+    https://community.opengroup.org/osdu/platform/data-flow/data-loading/osdu-cli/-/issues\033[39m
 
     Use `osdu version` to display the current version.
 
