@@ -131,7 +131,7 @@ class CliOsduClient(OsduClient):
             )
             sys.exit(1)
 
-    def _url_from_config(self, config_url_key: str, url_extra_path: str) -> str:
+    def url_from_config(self, config_url_key: str, url_extra_path: str) -> str:
         """Construct a url using values from configuration"""
         unit_url = self.config.get("core", config_url_key)
         url = urljoin(self.server_url, unit_url) + url_extra_path
@@ -147,7 +147,7 @@ class CliOsduClient(OsduClient):
             url_extra_path (str): extra path to add to the base path
             ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
         """
-        url = self._url_from_config(config_url_key, url_extra_path)
+        url = self.url_from_config(config_url_key, url_extra_path)
         response = self.get(url)
         if ok_status_codes is not None and response.status_code not in ok_status_codes:
             raise HTTPError(response=response)
@@ -163,7 +163,7 @@ class CliOsduClient(OsduClient):
             url_extra_path (str): extra path to add to the base path
             ok_status_codes (list, optional): accepted ok response codes. Defaults to None.
         """
-        url = self._url_from_config(config_url_key, url_extra_path)
+        url = self.url_from_config(config_url_key, url_extra_path)
         return self.get_returning_json(url, ok_status_codes)
 
     def cli_post_returning_json(
@@ -184,7 +184,7 @@ class CliOsduClient(OsduClient):
         Returns:
             dict: returned json
         """
-        url = self._url_from_config(config_url_key, url_extra_path)
+        url = self.url_from_config(config_url_key, url_extra_path)
         return self.post_returning_json(url, data, ok_status_codes)
 
     def cli_delete(
@@ -205,7 +205,7 @@ class CliOsduClient(OsduClient):
             [type]: [description]
         """
         try:
-            url = self._url_from_config(config_url_key, url_extra_path)
+            url = self.url_from_config(config_url_key, url_extra_path)
             self.delete(url, ok_status_codes)
             return
         except HTTPError as ex:
@@ -235,7 +235,7 @@ class CliOsduClient(OsduClient):
             url_extra_path (str): extra path to add to the base path
             ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
         """
-        url = self._url_from_config(config_url_key, url_extra_path)
+        url = self.url_from_config(config_url_key, url_extra_path)
         response = self.put(url, data)
         if ok_status_codes is not None and response.status_code not in ok_status_codes:
             raise HTTPError(response=response)
@@ -259,5 +259,5 @@ class CliOsduClient(OsduClient):
         Returns:
             dict: returned json
         """
-        url = self._url_from_config(config_url_key, url_extra_path)
+        url = self.url_from_config(config_url_key, url_extra_path)
         return self.put_returning_json(url, data, ok_status_codes)
