@@ -17,7 +17,7 @@ import os
 
 import click
 
-from osducli.click_cli import global_params
+from osducli.click_cli import CustomClickCommand, global_params
 from osducli.cliclient import handle_cli_exceptions
 from osducli.commands.config.consts import (
     MSG_HEADING_CURRENT_CONFIG_INFO,
@@ -28,7 +28,7 @@ from osducli.config import CLI_ENV_VAR_PREFIX, CLIConfig
 # from osducli.util import is_help_command
 
 
-@click.command()
+@click.command(cls=CustomClickCommand)
 @global_params
 @handle_cli_exceptions
 def _click_command(state):
