@@ -15,12 +15,12 @@
 import click
 from osdu.entitlements import EntitlementsClient
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-g", "--group", help="Email address of the group", required=True)
 @handle_cli_exceptions
 @command_with_output("")
