@@ -13,12 +13,12 @@
 """Custom cluster upgrade specific commands"""
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_SEARCH_URL
 
 
-@click.command()
+@click.command(cls=CustomClickCommand)
 @handle_cli_exceptions
 @command_with_output("sort_by(aggregations,&key)[*].{Key:key,Count:count}")
 def _click_command(state: State):
