@@ -18,7 +18,7 @@ from pathlib import Path
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_SCHEMA_URL
 from osducli.log import get_logger
@@ -29,7 +29,7 @@ logger = get_logger(__name__)
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option(
     "-p",
     "--path",
@@ -47,20 +47,31 @@ logger = get_logger(__name__)
     default="DEVELOPMENT",
     show_default=True,
 )
+@click.option(
+    "--overwrite-existing",
+    help="Overwrite any existing schema with the same version.",
+    is_flag=True,
+    show_default=True,
+)
 @click.option(
     "--self-contained",
     help="Make the schema self contained by including all references.",
+    is_flag=True,
     show_default=True,
 )
 @handle_cli_exceptions
 @command_with_output(None)
-def _click_command(state: State, path: str, kind: str, status: str, self_contained: bool):
+def _click_command(
+    state: State, path: str, kind: str, status: str, overwrite_existing: bool, self_contained: bool
+):
     """Add a schema"""
-    return add_schema(state, path, kind, status, self_contained)
+    return add_schema(state, path, kind, status, overwrite_existing, self_contained)
 
 
 # pylint: disable=too-many-locals
-def add_schema(state: State, path: str, kind: str, status: str, self_contained: bool) -> dict:
+def add_schema(
+    state: State, path: str, kind: str, status: str, overwrite_existing: bool, self_contained: bool
+) -> dict:
     """Add schemas to OSDU
 
     Args:
@@ -106,9 +117,15 @@ def add_schema(state: State, path: str, kind: str, status: str, self_contained:
                 schema_info = _get_schema_info(kind, status)
                 payload = {"schemaInfo": schema_info, "schema": schema_object}
 
-                response_json = connection.cli_post_returning_json(
-                    CONFIG_SCHEMA_URL, url, payload, [200, 201]
-                )
+                response_json = None
+                if overwrite_existing:
+                    response_json = connection.cli_put_returning_json(
+                        CONFIG_SCHEMA_URL, url, payload, [200, 201]
+                    )
+                else:
+                    response_json = connection.cli_post_returning_json(
+                        CONFIG_SCHEMA_URL, url, payload, [200, 201]
+                    )
                 responses.append(response_json)
 
     return responses
